import React, { forwardRef, useImperativeHandle, useMemo, useState } from 'react';
import { width } from '../../../constant/theme';
import ModalBottom from './ModalBottom';
import ModalCenter from './ModalCenter';
import ModalTop from './ModalTop';
const MainModal = /*#__PURE__*/forwardRef((_ref, ref) => {
  let { ...props
  } = _ref;
  const [modalData, setModalData] = useState({
    isVisible: false,
    title: '',
    body: '',
    description: '',
    image: null,
    type: '',
    onPress: () => {},
    leftIconName: '',
    rightIconName: '',
    message: ''
  });
  useImperativeHandle(ref, () => ({
    _showModal: data => showModal(data),
    _closeModal: () => closeModal()
  }));
  const ContentModal = useMemo(() => {
    if (!modalData.type) {
      console.warn('Invalid modal type, please return modal type one of [BOTTOM, CENTER]');
    } else if (modalData.type === 'BOTTOM') {
      return /*#__PURE__*/React.createElement(ModalBottom, {
        onBackdropPress: closeModal,
        onBackButtonPress: closeModal,
        isVisible: modalData === null || modalData === void 0 ? void 0 : modalData.isVisible,
        title: modalData === null || modalData === void 0 ? void 0 : modalData.title,
        body: modalData === null || modalData === void 0 ? void 0 : modalData.body,
        description: (modalData === null || modalData === void 0 ? void 0 : modalData.description) || '',
        localImage: modalData === null || modalData === void 0 ? void 0 : modalData.image,
        imageStyle: {
          height: width * 0.3
        },
        onPress: () => {
          closeModal();
          (modalData === null || modalData === void 0 ? void 0 : modalData.onPressBtn) && (modalData === null || modalData === void 0 ? void 0 : modalData.onPressBtn());
        }
      });
    } else if (modalData.type === 'CENTER') {
      return /*#__PURE__*/React.createElement(ModalCenter, {
        onBackdropPress: closeModal,
        onBackButtonPress: closeModal,
        isVisible: modalData === null || modalData === void 0 ? void 0 : modalData.isVisible,
        title: modalData === null || modalData === void 0 ? void 0 : modalData.title,
        body: modalData === null || modalData === void 0 ? void 0 : modalData.body,
        description: modalData.description,
        image: modalData === null || modalData === void 0 ? void 0 : modalData.image,
        onPress: modalData === null || modalData === void 0 ? void 0 : modalData.onPress
      });
    } else if (modalData.type === 'TOP') {
      return /*#__PURE__*/React.createElement(ModalTop, {
        onBackdropPress: closeModal,
        onBackButtonPress: closeModal,
        isVisible: modalData === null || modalData === void 0 ? void 0 : modalData.isVisible,
        onPress: modalData === null || modalData === void 0 ? void 0 : modalData.onPress,
        leftIconName: modalData === null || modalData === void 0 ? void 0 : modalData.leftIconName,
        rightIconName: modalData === null || modalData === void 0 ? void 0 : modalData.rightIconName,
        message: modalData === null || modalData === void 0 ? void 0 : modalData.message
      });
    } else {
      return null;
    }
  }, [modalData]);
  return ContentModal;

  function showModal(data) {
    setModalData(data);
  }

  function closeModal() {
    setModalData({
      isVisible: false,
      title: '',
      body: '',
      description: '',
      image: null,
      type: '',
      onPress: () => {}
    });
  }
});
export default MainModal;
//# sourceMappingURL=MainModal.js.map