import React, {
  forwardRef,
  useImperativeHandle,
  useMemo,
  useState,
} from 'react';
import { width } from '../../../constant/theme';
import ModalBottom from './ModalBottom';
import ModalCenter from './ModalCenter';
import ModalTop from './ModalTop';

const MainModal = forwardRef(({ ...props }, ref) => {
  const [modalData, setModalData] = useState({
    isVisible: false,
    title: '',
    body: '',
    description: '',
    image: null,
    type: '',
    onPress: () => {},
    leftIconName: '',
    rightIconName: '',
    message: '',
  });

  useImperativeHandle(ref, () => ({
    _showModal: (data) => showModal(data),
    _closeModal: () => closeModal(),
  }));

  const ContentModal = useMemo(() => {
    if (!modalData.type) {
      console.warn(
        'Invalid modal type, please return modal type one of [BOTTOM, CENTER]'
      );
    } else if (modalData.type === 'BOTTOM') {
      return (
        <ModalBottom
          onBackdropPress={closeModal}
          onBackButtonPress={closeModal}
          isVisible={modalData?.isVisible}
          title={modalData?.title}
          body={modalData?.body}
          description={modalData?.description || ''}
          localImage={modalData?.image}
          imageStyle={{ height: width * 0.3 }}
          onPress={() => {
            closeModal();
            modalData?.onPressBtn && modalData?.onPressBtn();
          }}
        />
      );
    } else if (modalData.type === 'CENTER') {
      return (
        <ModalCenter
          onBackdropPress={closeModal}
          onBackButtonPress={closeModal}
          isVisible={modalData?.isVisible}
          title={modalData?.title}
          body={modalData?.body}
          description={modalData.description}
          image={modalData?.image}
          onPress={modalData?.onPress}
        />
      );
    } else if (modalData.type === 'TOP') {
      return (
        <ModalTop
          onBackdropPress={closeModal}
          onBackButtonPress={closeModal}
          isVisible={modalData?.isVisible}
          onPress={modalData?.onPress}
          leftIconName={modalData?.leftIconName}
          rightIconName={modalData?.rightIconName}
          message={modalData?.message}
        />
      );
    } else {
      return null;
    }
  }, [modalData]);

  return ContentModal;

  function showModal(data) {
    setModalData(data);
  }

  function closeModal() {
    setModalData({
      isVisible: false,
      title: '',
      body: '',
      description: '',
      image: null,
      type: '',
      onPress: () => {},
    });
  }
});

export default MainModal;
